import { EntityRepository, getConnection, Repository } from "typeorm";
import { UpdateHomePagePromotionSectionDto } from "./dto/update-home-page-promotion-section.dto";
import { HomePagePromotionSectionEntity } from "./entities/home-page-promotion-section.entity";
import { CreateHomePagePromotionSectionDto } from "./dto/create-home-page-promotion-section.dto";

@EntityRepository(HomePagePromotionSectionEntity)
export class HomePagePromotionSectionRepository extends Repository<HomePagePromotionSectionEntity> {
    async createEntity(dto: CreateHomePagePromotionSectionDto): Promise<HomePagePromotionSectionEntity | Error> {
        try {
            const {
                image,
                title,
                description
            } = dto;
            const entity = this.create({
                image,
                title,
                description
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<HomePagePromotionSectionEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateHomePagePromotionSectionDto): Promise<HomePagePromotionSectionEntity | Error> {
        try {
            await this.update(id, {
                image: dto.image,
                title: dto.title,
                description: dto.description,
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<HomePagePromotionSectionEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(HomePagePromotionSectionEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}